<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- 引入 layui.css -->
    <link href="//unpkg.com/layui@2.9.8/dist/css/layui.css" rel="stylesheet">
    {% block css %}
    {% endblock css %}
    <title>{% block title %}{% endblock title %}</title>
</head>
<body>
{% block body %}
{% endblock body %}
<!-- 引入 layui.js -->
<script src="//unpkg.com/layui@2.9.8/dist/layui.js"></script>
{% block js %}
{% endblock js %}
</body>
</html>